@@ -48,7 +48,7 @@ sub test($$) {
 # run pl, expect $_
 sub pl(@) {
     at;
-    my @cmd = ($^X, '-W', $ENV{PLALT} // '../pl', @_);
+    my @cmd = ($^X, $ENV{PL_TESTOPT} // (), $ENV{PL_TESTALT} // '../pl', @_);
     my $name = join ' ', 'pl', map /[\s*?()[\]{}\$\\'";|&]|^$/ ? "'$_'" : $_, @_;
     if( $windows ) {
 	require Win32::ShellQuote;
